spacr.timelapse — spacr 0.5.0 documentation

# spacr.timelapse

## Module Contents

spacr.timelapse.link_by_iou(mask_prev, mask_next, iou_threshold=0.1)

spacr.timelapse.exponential_decay(x, a, b, c)

spacr.timelapse.preprocess_pathogen_data(pathogen_df)

spacr.timelapse.plot_data(measurement, group, ax, label, marker='o', linestyle='-')

spacr.timelapse.infected_vs_noninfected(result_df, measurement)

spacr.timelapse.save_figure(fig, src, figure_number)

spacr.timelapse.save_results_dataframe(df, src, results_name)

spacr.timelapse.summarize_per_well(peak_details_df)

spacr.timelapse.summarize_per_well_inf_non_inf(peak_details_df)

spacr.timelapse.analyze_calcium_oscillations(db_loc, measurement='cell_channel_1_mean_intensity', size_filter='cell_area', fluctuation_threshold=0.25, num_lines=None, peak_height=0.01, pathogen=None, cytoplasm=None, remove_transient=True, verbose=False, transience_threshold=0.9)